# CHANGELOG

<!-- version list -->

## v1.1.0 (2025-10-21)

### Chores

- Examples/adobe/basic_usage.py
  ([`e19ead2`](https://github.com/karlorz/adobe-helper/commit/e19ead27c40ed7be54c935969a61534f547246e7))

### Features

- Implement multi-tenant architecture and dynamic endpoints
  ([`d5b90bf`](https://github.com/karlorz/adobe-helper/commit/d5b90bf60accbf1f06df1d17d6e75a497f2479f2))

### Testing

- Docker example
  ([`679a21f`](https://github.com/karlorz/adobe-helper/commit/679a21fb1c9aacd96f8841da18a7bd82a3904dc2))


## v1.0.6 (2025-10-17)

### Bug Fixes

- Ci
  ([`24f8e2b`](https://github.com/karlorz/adobe-helper/commit/24f8e2b248036133f912b69e26b64f97f3fd6c61))


## v1.0.5 (2025-10-17)

### Bug Fixes

- Ci
  ([`a9bc20c`](https://github.com/karlorz/adobe-helper/commit/a9bc20c0387676f2519339158e27e274377a164f))


## v1.0.4 (2025-10-17)

### Bug Fixes

- Ci
  ([`ecc318d`](https://github.com/karlorz/adobe-helper/commit/ecc318d47250da76003f395879334c96b1a6793f))

### Continuous Integration

- Rename futunn-helper to adobe-helper and update metadata
  ([`2a254fa`](https://github.com/karlorz/adobe-helper/commit/2a254fa04099f5de2f22432c3ec314dac04f7c77))


## v1.0.3 (2025-10-17)

### Bug Fixes

- Improve type safety and error handling across modules
  ([`83e4129`](https://github.com/karlorz/adobe-helper/commit/83e4129e1acb345091e2206af089bbe1d63b9f10))


## v1.0.2 (2025-10-17)

### Bug Fixes

- Refactor imports and formatting for consistency
  ([`f09b04e`](https://github.com/karlorz/adobe-helper/commit/f09b04e64357efa455eb2c2940477201456017ce))


## v1.0.1 (2025-10-17)


## v1.0.0 (2025-10-17)

- Initial Release
